PCB Environment: dsn::Shape Struct Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
dsn::Shape Struct Reference

## Public Member Functions
double | minExtent () const
double | maxExtent () const
bool | operator== (const Shape &) const
std::string | str (bool verbose=false) const
void | recenter ()

## Data Fields
std::string | geometry
std::vector< double > | values
int | z
Path | path

The documentation for this struct was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Loaders/DSN.hpp